@@ -129,36 +129,13 @@ class cgfb_smarty
    */
   public static function login_button($params, &$smarty)
   {
-//     $output = '';
-
-//     // javascript sdk.
-//     $output = '<fb:login-button';
-//     if( isset($params['width']) )
-//       {
-// 	$output .= ' width='.(int)$params['width'];
-//       }
-//     if( isset($params['faces']) && (int)$params['face'] > 0 )
-//       {
-// 	$output .= ' show-faces="1"';
-//       }
-//     if( isset($params['max_rows']) )
-//       {
-// 	$output .= ' max-rows='.(int)$params['max_rows'];
-//       }
-//     $perms = self::get_preference('fb_perms');
-//     if( $perms )
-//       {
-// 	$output .= ' perms="'.$perms.'"';
-//       }
-	
-//     $output .= '></fb:login-button>';
-
-   $output = '';
+    $output = '';
 
     // static html
     if( cgfb::uid() ) return;
 
     $url = cgfb::get_login_url();
+    $url = str_replace('&','&amp;',$url);
     if( isset($params['urlonly']) )
       {
 	$output = $url;
@@ -509,6 +486,9 @@ class cgfb_smarty
    * xid:  string
    * prop: string name,value[,href]
    * data: string name,value
+   * action1: string name::href
+   * action2: string name::href
+   * action3: string name::href
    * image1: string src:::href
    * image2: string src:::href
    * image3: string src:::href
@@ -518,12 +498,12 @@ class cgfb_smarty
    */
   public static function wallpost($params,&$smarty)
   {
-    $to = get_parameter_value($params,'me');
-    $msg = get_parameter_value($params,'msg');
-    $name = get_parameter_value($params,'name');
-    $href = get_parameter_value($params,'href');
-    $caption = get_parameter_value($params,'caption');
-    $description = get_parameter_value($params,'desc');
+    $to = trim(get_parameter_value($params,'to','me'));
+    $msg = trim(get_parameter_value($params,'msg'));
+    $name = trim(get_parameter_value($params,'name'));
+    $href = trim(get_parameter_value($params,'href'));
+    $caption = trim(get_parameter_value($params,'caption'));
+    $description = trim(strip_tags(get_parameter_value($params,'desc')));
 
     if( !$msg ) return;
     try
@@ -571,6 +551,15 @@ class cgfb_smarty
 		    list($s,$h) = explode(':::',$value,2);
 		    $att->add_media('image',$s,$h);
 		  }
+                else if( startswith($key,'action') )
+                  {
+                    list($n,$h) = explode(':::',$value,2);
+                    if( empty($h) )
+                      list($n,$h) = explode(',',$value,2);
+                    $tmp = (int)substr($key,strlen('action'));
+                    if( $tmp < 1 || $tmp > 3 ) continue;
+		    $post->add_action($n,$h);
+                  }
 	      }
 
 	    $post->set_attachment($att);
@@ -578,7 +567,6 @@ class cgfb_smarty
 
 	$data = array_merge(array('method'=>'stream.publish'),$post->to_array());
 	$res = cgfb::rest($data);
-
 	if( isset($params['assign']) )
 	  {
 	    $smarty->assign($params['assign'],$res);
@@ -589,6 +577,7 @@ class cgfb_smarty
     catch( Exception $e )
       {
 	// nothing to do here.
+        die('ERROR: '.$e->getMessage());
       }
   }
 
@@ -602,69 +591,52 @@ class cgfb_smarty
    * action1: string - name=link for sending links
    * action2: string - name=link for sending links
    * action3: string - name=link for sending links
-   * attachment: attachment object 
    */
   public static function status($params,&$smarty)
   {
-    $to = get_parameter_value($params,'to');
-    $msg = get_parameter_value($params,'msg');
-    
+    $to = get_parameter_value($params,'to','me');
+    $msg = get_parameter_value($params,'msg');    
     if( !$msg ) return;
 
     try
       {
 	$obj = new cgfb_post($msg,$to);
 	$data = $obj->to_array();
-	debug_display($data); die();
+	$args = array('as_app','action1','action2','action3');
+	$argmap = array('desc'=>'description');
+	foreach( $params as $key => $value )
+	  {
+	    if( in_array($key,$args) )
+	      {
+		// translate our name to facebooks param name.
+		if( isset($argmap[$key]) )
+		  {
+		    $key = $argmap[$key];
+		  }
+
+		// special cases for certain params
+		if( $key == 'to' )
+		  {
+		    $uri = $params['to'].'/feed';
+		    unset($params['to']);
+		    $data['uri'] = $uri;
+		    continue;
+		  }
+
+		$data[$key] = $value;
+	      }
+	  }
+
+	$data = array_merge(array('method'=>'stream.publish'),$data);
+	$res = cgfb::rest($data);
       }
     catch( Exception $e )
       {
-	// do nothing.
+	// nothing to do here.
+        die('ERROR: '.$e->getMessage());
       }
 
-    if( !isset($params['msg']) ) return;
-    if( !isset($params['to']) ) 
-      {
-	$params['to'] = 'me';
-      }
-    
-    $args = array('to','msg','link','picture','name','caption','desc','as_app','actions');
-    $argmap = array('msg'=>'message','desc'=>'description');
-    $data = array();
-    foreach( $params as $key => $value )
-      {
-
-	if( $key == 'actions' )
-	  {
-	    if( !is_array($value) )
-	      {
-		$value = cge_array::explode_with_key($value,'=',',');
-	      }
-	  }
-
-	if( in_array($key,$args) )
-	  {
-	    // translate our name to facebooks param name.
-	    if( isset($argmap[$key]) )
-	      {
-		$key = $argmap[$key];
-	      }
-
-	    // special cases for certain params
-	    if( $key == 'to' )
-	      {
-		$uri = $params['to'].'/feed';
-		unset($params['to']);
-		$data['uri'] = $uri;
-		continue;
-	      }
-
-	    $data[$key] = $value;
-	  }
-      }
-
-    $output = self::send($data,$smarty);
-    return $output;
+    return $res;
   }
 
 
@@ -806,6 +778,8 @@ class cgfb_smarty
 
     $output = '';
     $mod = cge_utils::get_module('CGFBApp');
+    $appid = $mod->GetPreference('fb_appid');
+    $smarty->assign('fb_appid',$appid);
     if( $async )
       {
 	$output = $mod->ProcessTemplateFromDatabase('fbinit_async');
@@ -876,4 +850,4 @@ class cgfb_smarty
 #
 # EOF
 #
-?>
\ No newline at end of file
+?>
